#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IFIX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IFIX_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/ifix.hpp>

#endif
